==> monaco-vscode-view-common-service-override-11.1.1.tgz: package/vscode/src/vs/workbench/contrib/sash/browser/sash.contribution.js <==
import { localize } from 'vscode/vscode/vs/nls';
import { Extensions as Extensions$1 } from 'vscode/vscode/vs/platform/configuration/common/configurationRegistry';
import { Registry } from 'vscode/vscode/vs/platform/registry/common/platform';
import { workbenchConfigurationNodeBase } from 'vscode/vscode/vs/workbench/common/configuration';
import { Extensions } from 'vscode/vscode/vs/workbench/common/contributions';
import { SashSettingsController } from './sash.js';
import { isIOS } from 'vscode/vscode/vs/base/common/platform';

( (Registry.as(Extensions.Workbench)))
    .registerWorkbenchContribution(SashSettingsController, 3 );
( (Registry.as(Extensions$1.Configuration)))
    .registerConfiguration({
    ...workbenchConfigurationNodeBase,
    properties: {
        'workbench.sash.size': {
            type: 'number',
            default: isIOS ? 20 : 4,
            minimum: 1,
            maximum: 20,
            description: ( localize(
                4207,
                "Controls the feedback area size in pixels of the dragging area in between views/editors. Set it to a larger value if you feel it's hard to resize views using the mouse."
            ))
        },
        'workbench.sash.hoverDelay': {
            type: 'number',
            default: 300,
            minimum: 0,
            maximum: 2000,
            description: ( localize(
                4208,
                "Controls the hover feedback delay in milliseconds of the dragging area in between views/editors."
            ))
        },
    }
});

==> monaco-vscode-view-common-service-override-12.0.1.tgz: package/vscode/src/vs/workbench/contrib/sash/browser/sash.contribution.js <==

import { localize } from 'vscode/vscode/vs/nls';
import { Extensions as Extensions$1 } from 'vscode/vscode/vs/platform/configuration/common/configurationRegistry';
import { LifecyclePhase } from 'vscode/vscode/vs/workbench/services/lifecycle/common/lifecycle';
import { Registry } from 'vscode/vscode/vs/platform/registry/common/platform';
import { workbenchConfigurationNodeBase } from 'vscode/vscode/vs/workbench/common/configuration';
import { Extensions } from 'vscode/vscode/vs/workbench/common/contributions';
import { SashSettingsController } from './sash.js';
import { isIOS } from 'vscode/vscode/vs/base/common/platform';

( Registry.as(Extensions.Workbench))
    .registerWorkbenchContribution(SashSettingsController, LifecyclePhase.Restored);
( Registry.as(Extensions$1.Configuration))
    .registerConfiguration({
    ...workbenchConfigurationNodeBase,
    properties: {
        'workbench.sash.size': {
            type: 'number',
            default: isIOS ? 20 : 4,
            minimum: 1,
            maximum: 20,
            description: ( localize(
                8403,
                "Controls the feedback area size in pixels of the dragging area in between views/editors. Set it to a larger value if you feel it's hard to resize views using the mouse."
            ))
        },
        'workbench.sash.hoverDelay': {
            type: 'number',
            default: 300,
            minimum: 0,
            maximum: 2000,
            description: ( localize(
                8404,
                "Controls the hover feedback delay in milliseconds of the dragging area in between views/editors."
            ))
        },
    }
});
